summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp b/experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp
index 7900d3cd9..fe1dbbf3a 100644
--- a/experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp
+++ b/experimental/tqtinterface/qt4/src/widgets/tqtextedit.cpp
@@ -891,19 +891,19 @@ static bool block_set_tqalignment = FALSE;
*/
/*!
- Constructs an empty TQTextEdit called \a name, with tqparent \a
- tqparent.
+ Constructs an empty TQTextEdit called \a name, with parent \a
+ parent.
*/
-TQTextEdit::TQTextEdit( TQWidget *tqparent, const char *name )
- : TQScrollView( tqparent, name, (WFlags)(TQt::WStaticContents | TQt::WNoAutoErase) ),
+TQTextEdit::TQTextEdit( TQWidget *parent, const char *name )
+ : TQScrollView( parent, name, (WFlags)(TQt::WStaticContents | TQt::WNoAutoErase) ),
doc( new TQTextDocument( 0 ) ), undoRedoInfo( doc )
{
init();
}
/*!
- Constructs a TQTextEdit called \a name, with tqparent \a tqparent. The
+ Constructs a TQTextEdit called \a name, with parent \a parent. The
text edit will display the text \a text using context \a context.
The \a context is a path which the text edit's TQMimeSourceFactory
@@ -923,8 +923,8 @@ TQTextEdit::TQTextEdit( TQWidget *tqparent, const char *name )
*/
TQTextEdit::TQTextEdit( const TQString& text, const TQString& context,
- TQWidget *tqparent, const char *name)
- : TQScrollView( tqparent, name, (WFlags)(TQt::WStaticContents | TQt::WNoAutoErase) ),
+ TQWidget *parent, const char *name)
+ : TQScrollView( parent, name, (WFlags)(TQt::WStaticContents | TQt::WNoAutoErase) ),
doc( new TQTextDocument( 0 ) ), undoRedoInfo( doc )
{
init();
@@ -3421,14 +3421,14 @@ void TQTextEdit::repaintChanged()
}
#ifndef TQT_NO_MIME
-TQTextDrag *TQTextEdit::dragObject( TQWidget *tqparent ) const
+TQTextDrag *TQTextEdit::dragObject( TQWidget *parent ) const
{
if ( !doc->hasSelection( TQTextDocument::Standard ) ||
doc->selectedText( TQTextDocument::Standard ).isEmpty() )
return 0;
if ( textFormat() != TQt::RichText )
- return new TQTextDrag( doc->selectedText( TQTextDocument::Standard ), tqparent );
- TQRichTextDrag *drag = new TQRichTextDrag( tqparent );
+ return new TQTextDrag( doc->selectedText( TQTextDocument::Standard ), parent );
+ TQRichTextDrag *drag = new TQRichTextDrag( parent );
drag->setPlainText( doc->selectedText( TQTextDocument::Standard ) );
drag->setRichText( doc->selectedText( TQTextDocument::Standard, TRUE ) );
return drag;
@@ -6278,7 +6278,7 @@ TQTextEditOptimPrivate::Tag * TQTextEdit::optimAppendTag( int index, const TQStr
t->index = index;
t->tag = tag;
t->leftTag = 0;
- t->tqparent = 0;
+ t->parent = 0;
t->prev = d->od->lastTag;
if ( d->od->lastTag )
d->od->lastTag->next = t;
@@ -6307,7 +6307,7 @@ TQTextEditOptimPrivate::Tag *TQTextEdit::optimInsertTag(int line, int index, con
t->index = index;
t->tag = tag;
t->leftTag = 0;
- t->tqparent = 0;
+ t->parent = 0;
t->next = 0;
t->prev = 0;
@@ -6448,7 +6448,7 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
: TQTextEditOptimPrivate::Color;
if ( tagStr[0] == '/' ) {
// this is a right-tag - search for the left-tag
// and possible tqparent tag
cur = tag->prev;
if ( !cur ) {
#ifdef TQT_CHECK_RANGE
@@ -6464,13 +6464,13 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
if ( !tmp ) {
if ( (("/" + cur->tag) == tag->tag) ||
(tag->tag == "/font" && cur->tag.left(4) == "font") ) {
// set up the left and tqparent of this tag
tag->leftTag = cur;
tmp = cur->prev;
- if ( tmp && tmp->tqparent ) {
- tag->tqparent = tmp->tqparent;
+ if ( tmp && tmp->parent ) {
+ tag->parent = tmp->parent;
} else if ( tmp && !tmp->leftTag ) {
- tag->tqparent = tmp;
+ tag->parent = tmp;
}
break;
} else if ( !cur->leftTag ) {
@@ -6489,7 +6489,7 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
tag->underline = underline > 0;
tmp = tag->prev;
while ( tmp && tmp->leftTag ) {
- tmp = tmp->leftTag->tqparent;
+ tmp = tmp->leftTag->parent;
}
if ( tmp ) {
tag->bold |= tmp->bold;
@@ -6812,9 +6812,9 @@ TQTextEditOptimPrivate::Tag * TQTextEdit::optimPreviousLeftTag( int line )
}
if ( ftag ) {
- if ( ftag && ftag->tqparent ) // use the open tqparent tag
- ftag = ftag->tqparent;
- else if ( ftag && ftag->leftTag ) // this is a right-tag with no tqparent
+ if ( ftag && ftag->parent ) // use the open parent tag
+ ftag = ftag->parent;
+ else if ( ftag && ftag->leftTag ) // this is a right-tag with no parent
ftag = 0;
}
return ftag;
@@ -6848,7 +6848,7 @@ void TQTextEdit::optimSetTextFormat( TQTextDocument * td, TQTextCursor * cur,
tag = tag->prev;
while ( tag && (tag->type == TQTextEditOptimPrivate::Format ||
tag->leftTag) ) {
- tag = tag->leftTag ? tag->tqparent : tag->prev;
+ tag = tag->leftTag ? tag->parent : tag->prev;
}
}
if ( tag ) {
@@ -6934,8 +6934,8 @@ void TQTextEdit::optimDrawContents( TQPainter * p, int clipx, int clipy,
tmp = 0;
if ( tag->prev && !tag->prev->leftTag ) {
tmp = tag->prev;
- } else if ( tag->prev && tag->prev->tqparent ) {
- tmp = tag->prev->tqparent;
+ } else if ( tag->prev && tag->prev->parent ) {
+ tmp = tag->prev->parent;
}
if ( (tag->index - lastIndex) > 0 && tmp ) {
optimSetTextFormat( td, &cur, &f, lastIndex, tag->index, tmp );
@@ -6945,8 +6945,8 @@ void TQTextEdit::optimDrawContents( TQPainter * p, int clipx, int clipy,
tag = tag->next;
}
// Step 3 - color last part of the line - if necessary
- if ( tmp && tmp->tqparent )
- tmp = tmp->tqparent;
+ if ( tmp && tmp->parent )
+ tmp = tmp->parent;
if ( (cur.paragraph()->length()-1 - lastIndex) > 0 && tmp && !tmp->leftTag ) {
optimSetTextFormat( td, &cur, &f, lastIndex,
cur.paragraph()->length() - 1, tmp );
@@ -6958,8 +6958,8 @@ void TQTextEdit::optimDrawContents( TQPainter * p, int clipx, int clipy,
// tag = d->od->tags;
// qWarning("###");
// while ( tag ) {
-// qWarning( "Tag: %p, tqparent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
-// tag->tqparent, tag->leftTag, tag->tag.latin1(), tag->tqparent ? tag->tqparent->tag.latin1():"<none>",
+// qWarning( "Tag: %p, parent: %09p, leftTag: %09p, Name: %-15s, ParentName: %s, %d%d%d", tag,
+// tag->parent, tag->leftTag, tag->tag.latin1(), tag->parent ? tag->parent->tag.latin1():"<none>",
// tag->bold, tag->italic, tag->underline );
// tag = tag->next;
// }
@@ -7404,8 +7404,8 @@ void TQTextEdit::optimCheckLimit( const TQString& str )
itr = d->od->tags;
while ( itr ){
for ( tmp = lst.first(); tmp; tmp = lst.next() ) {
- if ( itr->tqparent == tmp )
- itr->tqparent = 0;
+ if ( itr->parent == tmp )
+ itr->parent = 0;
if ( itr->leftTag == tmp )
itr->leftTag = 0;
}
@@ -6448,7 +6448,7 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
if ( tagStr[0] == '/' ) {
// this is a right-tag - search for the left-tag
- // and possible tqparent tag
+ // and possible parent tag
cur = tag->prev;
if ( !cur ) {
@@ -6464,13 +6464,13 @@ void TQTextEdit::optimParseTags( TQString * line, int lineNo, int indexOffset )
if ( (("/" + cur->tag) == tag->tag) ||
(tag->tag == "/font" && cur->tag.left(4) == "font") ) {
- // set up the left and tqparent of this tag
+ // set up the left and parent of this tag
tag->leftTag = cur;
tmp = cur->prev;